.. clap

Welcome to clap's documentation!
================================

(C)ommand (L)ine (A)rgument (P)arsing... A thin wrapper around the standard argparse library.

.. toctree::
   :maxdepth: -1
   :caption: Table of Contents

    API Reference <modules>
    CHANGELOG <changelog>
    CONTRIBUTING <contributing>
    README <readme>


Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
